@@ -6,16 +6,18 @@ sub Mojo::Webqq::Client::_get_qrlogin_pic {
     $self->info("正在获取登录二维码...");
     my $api = 'https://ssl.ptlogin2.qq.com/ptqrshow';
     my @query_string = (
-        appid => $self->g_appid,
-        e     => 0,
+        appid => 501004106,
+        e     => 2,
         l     => 'M',
-        s     => 5,
+        s     => 3,
         d     => 72,
         v     => 4,
         t     => rand(),
+        daid  => 164,
+        pt_3rd_aid => 0,
     );  
     my $url = $self->gen_url($api,@query_string);
-    my $data = $self->http_get($url,{Referer=>'https://ui.ptlogin2.qq.com/cgi-bin/login?daid=164&target=self&style=16&mibao_css=m_webqq&appid=501004106&enable_qlogin=0&no_verifyimg=1&s_url=http%3A%2F%2Fw.qq.com%2Fproxy.html&f_url=loginerroralert&strong_login=1&login_state=10&t=20131024001'});
+    my $data = $self->http_get($url,{Referer=>'https://xui.ptlogin2.qq.com/cgi-bin/xlogin?daid=164&target=self&style=40&pt_disable_pwd=1&mibao_css=m_webqq&appid=501004106&enable_qlogin=0&no_verifyimg=1&s_url=http%3A%2F%2Fw.qq.com%2Fproxy.html&f_url=loginerroralert&strong_login=1&login_state=10&t=20131024001',ua_debug_res_body=>0});
     if( not defined $data){
         $self->error("登录二维码下载失败");
         return 0;
