@@ -5,8 +5,8 @@ sub Mojo::Webqq::Client::_get_vfwebqq {
     my @query_string = (
         ptwebqq    =>  $self->ptwebqq,
         clientid   =>  $self->clientid,
-        psessionid =>  undef,
-        t          =>  rand(), 
+        psessionid =>  $self->psessionid,
+        t          =>  time(),
     );  
     my $headers = {
         Referer => 'http://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',
@@ -16,7 +16,7 @@ sub Mojo::Webqq::Client::_get_vfwebqq {
     my $json = $self->http_get($self->gen_url($api_url,@query_string),$headers);
     return undef unless defined $json;
     if($json->{retcode}!=0){
-        $self->error("获取数据验证参数失败...\n");
+        $self->error("获取数据验证参数失败...");
         return 0;
     }
     $self->vfwebqq($json->{result}{vfwebqq});
