@@ -31,7 +31,7 @@ sub call{
         my $sender_nick = $msg->sender->displayname;
         my $user_nick = $msg->receiver->displayname;
         return if $is_need_at and $msg->type eq "group_message" and !$msg->is_at;
-        if(!$is_need_at and ref $data->{keyword} eq "ARRAY"){
+        if(ref $data->{keyword} eq "ARRAY"){
             return if not first { $msg->content =~ /\Q$_\E/} @{$data->{keyword}};
         }
         if($msg->type eq 'group_message'){
